Engine
------

Problematic
^^^^^^^^^^^

* How to auto continue?
* How to auto save?
* How to implement a proper debugger?
* How to get subjects related to a tested subject?
* How to work with different database types?
* How to sort our outputs?

Documentation
^^^^^^^^^^^^^

.. automodule:: PyFunceble.engine
   :members:
   :private-members:


:code:`AutoContinue()`
""""""""""""""""""""""

.. autoclass:: PyFunceble.engine.auto_continue.AutoContinue
    :members:
    :private-members:

:code:`AutoSave()`
""""""""""""""""""

.. autoclass:: PyFunceble.engine.auto_save.AutoSave
    :members:
    :private-members:

:code:`Logger()`
""""""""""""""""

.. autoclass:: PyFunceble.engine.logger.Logger
    :members:
    :private-members:

:code:`Mining()`
""""""""""""""""

.. autoclass:: PyFunceble.engine.mining.Mining
    :members:
    :private-members:

:code:`Sort()`
""""""""""""""

.. autoclass:: PyFunceble.engine.sort.Sort
    :members:
    :private-members: